@@ -44,7 +44,7 @@ let list_modules ~path =
 
 let reset_modules box =
   Listbox.delete box ~first:(`Num 0) ~last:`End;
-  module_list := Sort.list (Jg_completion.lt_string ~nocase:true)
+  module_list := List.sort (Jg_completion.compare_string ~nocase:true)
       (list_modules ~path:!Config.load_path);
   Listbox.insert box ~index:`End ~texts:!module_list;
   Jg_box.recenter box ~index:(`Num 0)
@@ -76,7 +76,7 @@ let view_symbol ~kind ~env ?path id =
             [Sig_typext (Ident.create name,
 			 {Types.ext_type_path = cpath;
 			  ext_type_params = args;
-			  ext_args = cd.cstr_args;
+			  ext_args = Cstr_tuple cd.cstr_args;
 			  ext_ret_type = (if cd.cstr_generalized
 			                  then Some cd.cstr_res else None);
 			  ext_private = cd.cstr_private;
@@ -609,7 +609,7 @@ object (self)
     let display index =
       let `Num pos = Listbox.index box ~index in
       try
-        let li, k = List.nth l pos in
+        let li, k = try List.nth l pos with Failure _ -> raise Exit in
         self#hide_after (n+1);
         if !current = Some (li,k) then () else
         let path =
@@ -623,7 +623,7 @@ object (self)
         in
         current := Some (li,k);
         view_symbol li ~kind:k ~env ?path
-      with Failure "nth" -> ()
+      with Exit -> ()
     in
     Jg_box.add_completion box ~double:false ~action:display;
     bind box ~events:[`KeyRelease] ~fields:[`Char]
